==> cscec5b-wzxt-api-3.0.0-20210323.082747-176-sources.jar: com/ejianc/business/wzxt/vo/WeighBillVO.java <==
package com.ejianc.business.wzxt.vo;

import java.math.BigDecimal;
import java.sql.Timestamp;

/**
 * <p>
 * 磅单
 * </p>
 *
 * @author weixha
 * @since 2020-07-11
 */
public class WeighBillVO {

    private static final long serialVersionUID = 1L;

    /**
     * 磅单主键
     */
    private String pkWeighBill;
    /**
     * 磅单编号
     */
    private String weighCode;
    /**
     * 车牌号
     */
    private String plateNumber;
    /**
     * 发货单位、供应商
     */
    private String forwardingUnit;
    /**
     * 收货单位、收货项目
     */
    private String consigneeUnit;
    /**
     * 物料主键
     */
    private String pkMaterial;
    /**
     * 物料名称
     */
    private String materialName;
    /**
     * 规格型号
     */
    private String materialSpec;
    /**
     * 毛重
     */
    private BigDecimal grossWeight;
    /**
     * 皮重
     */
    private BigDecimal tareWeight;
    /**
     * 净重
     */
    private BigDecimal netWeight;
    /**
     * 重量单位
     */
    private String weightUnit;
    /**
     * 毛重时间
     */
    private String grossTime;
    /**
     * 皮重时间
     */
    private String tareTime;
    private String remark;
    /**
     * 轻量化平台组合ID  发货单ID&发货单子表ID
     */
    private String lpId;
    /**
     * 来源称重系统称重结果ID
     */
    private String thirdWeighId;
    /**
     * 发货单主键
     */
    private String pkDelivery;
    /**
     * 发货单子表主键
     */
    private String pkDeliveryB;

    /**
     * 过磅申请主键
     */
    private String pkWeighApply;
    /**
     * 验收单主键
     */
    private String pkCheck;

    /**
     * 验收状态  0-未验收  1- 已验收
     */
    private Integer checkStatus;
    /**
     * 数据来源
     */
    private String source;
    /**
     * 时间戳
     */
    private Timestamp ts;

    public String getPkWeighBill() {
        return pkWeighBill;
    }

    public void setPkWeighBill(String pkWeighBill) {
        this.pkWeighBill = pkWeighBill;
    }

    public String getWeighCode() {
        return weighCode;
    }

    public void setWeighCode(String weighCode) {
        this.weighCode = weighCode;
    }

    public String getPlateNumber() {
        return plateNumber;
    }

    public void setPlateNumber(String plateNumber) {
        this.plateNumber = plateNumber;
    }

    public String getForwardingUnit() {
        return forwardingUnit;
    }

    public void setForwardingUnit(String forwardingUnit) {
        this.forwardingUnit = forwardingUnit;
    }

    public String getConsigneeUnit() {
        return consigneeUnit;
    }

    public void setConsigneeUnit(String consigneeUnit) {
        this.consigneeUnit = consigneeUnit;
    }

    public String getPkMaterial() {
        return pkMaterial;
    }

    public void setPkMaterial(String pkMaterial) {
        this.pkMaterial = pkMaterial;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public String getMaterialSpec() {
        return materialSpec;
    }

    public void setMaterialSpec(String materialSpec) {
        this.materialSpec = materialSpec;
    }

    public BigDecimal getGrossWeight() {
        return grossWeight;
    }

    public void setGrossWeight(BigDecimal grossWeight) {
        this.grossWeight = grossWeight;
    }

    public BigDecimal getTareWeight() {
        return tareWeight;
    }

    public void setTareWeight(BigDecimal tareWeight) {
        this.tareWeight = tareWeight;
    }

    public BigDecimal getNetWeight() {
        return netWeight;
    }

    public void setNetWeight(BigDecimal netWeight) {
        this.netWeight = netWeight;
    }

    public String getWeightUnit() {
        return weightUnit;
    }

    public void setWeightUnit(String weightUnit) {
        this.weightUnit = weightUnit;
    }

    public String getGrossTime() {
        return grossTime;
    }

    public void setGrossTime(String grossTime) {
        this.grossTime = grossTime;
    }

    public String getTareTime() {
        return tareTime;
    }

    public void setTareTime(String tareTime) {
        this.tareTime = tareTime;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public String getLpId() {
        return lpId;
    }

    public void setLpId(String lpId) {
        this.lpId = lpId;
    }

    public String getThirdWeighId() {
        return thirdWeighId;
    }

    public void setThirdWeighId(String thirdWeighId) {
        this.thirdWeighId = thirdWeighId;
    }

    public String getPkDelivery() {
        return pkDelivery;
    }

    public void setPkDelivery(String pkDelivery) {
        this.pkDelivery = pkDelivery;
    }

    public String getPkDeliveryB() {
        return pkDeliveryB;
    }

    public void setPkDeliveryB(String pkDeliveryB) {
        this.pkDeliveryB = pkDeliveryB;
    }

    public String getPkWeighApply() {
        return pkWeighApply;
    }

    public void setPkWeighApply(String pkWeighApply) {
        this.pkWeighApply = pkWeighApply;
    }

    public String getPkCheck() {
        return pkCheck;
    }

    public void setPkCheck(String pkCheck) {
        this.pkCheck = pkCheck;
    }

    public Integer getCheckStatus() {
        return checkStatus;
    }

    public void setCheckStatus(Integer checkStatus) {
        this.checkStatus = checkStatus;
    }

    public String getSource() {
        return source;
    }

    public void setSource(String source) {
        this.source = source;
    }

    public Timestamp getTs() {
        return ts;
    }

    public void setTs(Timestamp ts) {
        this.ts = ts;
    }
}

==> cscec5b-wzxt-api-3.0.1-20230912.092818-336-sources.jar: com/ejianc/business/wzxt/vo/WeighBillVO.java <==
package com.ejianc.business.wzxt.vo;

import java.math.BigDecimal;
import java.sql.Timestamp;

/**
 * <p>
 * 磅单
 * </p>
 *
 * @author weixha
 * @since 2020-07-11
 */
public class WeighBillVO {

    private static final long serialVersionUID = 1L;

    /**
     * 磅单主键
     */
    private String pkWeighBill;
    /**
     * 磅单编号
     */
    private String weighCode;
    /**
     * 车牌号
     */
    private String plateNumber;
    /**
     * 发货单位、供应商
     */
    private String forwardingUnit;
    /**
     * 收货单位、收货项目
     */
    private String consigneeUnit;
    /**
     * 物料主键
     */
    private String pkMaterial;
    /**
     * 物料名称
     */
    private String materialName;
    /**
     * 规格型号
     */
    private String materialSpec;
    /**
     * 毛重
     */
    private BigDecimal grossWeight;
    /**
     * 皮重
     */
    private BigDecimal tareWeight;
    /**
     * 净重
     */
    private BigDecimal netWeight;
    /**
     * 重量单位
     */
    private String weightUnit;
    /**
     * 毛重时间
     */
    private String grossTime;
    /**
     * 皮重时间
     */
    private String tareTime;
    private String remark;
    /**
     * 轻量化平台组合ID  发货单ID&发货单子表ID
     */
    private String lpId;
    /**
     * 来源称重系统称重结果ID
     */
    private String thirdWeighId;
    /**
     * 发货单主键
     */
    private String pkDelivery;
    /**
     * 发货单子表主键
     */
    private String pkDeliveryB;

    /**
     * 过磅申请主键
     */
    private String pkWeighApply;
    /**
     * 验收单主键
     */
    private String pkCheck;

    /**
     * 验收状态  0-未验收  1- 已验收
     */
    private Integer checkStatus;
    /**
     * 数据来源
     */
    private String source;
    /**
     * 时间戳
     */
    private Timestamp ts;
    /**
     * 发货量
     */
    private BigDecimal shipment;
    /**
     * 发货单位
     */
    private String shipedUnit;

    public String getPkWeighBill() {
        return pkWeighBill;
    }

    public void setPkWeighBill(String pkWeighBill) {
        this.pkWeighBill = pkWeighBill;
    }

    public String getWeighCode() {
        return weighCode;
    }

    public void setWeighCode(String weighCode) {
        this.weighCode = weighCode;
    }

    public String getPlateNumber() {
        return plateNumber;
    }

    public void setPlateNumber(String plateNumber) {
        this.plateNumber = plateNumber;
    }

    public String getForwardingUnit() {
        return forwardingUnit;
    }

    public void setForwardingUnit(String forwardingUnit) {
        this.forwardingUnit = forwardingUnit;
    }

    public String getConsigneeUnit() {
        return consigneeUnit;
    }

    public void setConsigneeUnit(String consigneeUnit) {
        this.consigneeUnit = consigneeUnit;
    }

    public String getPkMaterial() {
        return pkMaterial;
    }

    public void setPkMaterial(String pkMaterial) {
        this.pkMaterial = pkMaterial;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public String getMaterialSpec() {
        return materialSpec;
    }

    public void setMaterialSpec(String materialSpec) {
        this.materialSpec = materialSpec;
    }

    public BigDecimal getGrossWeight() {
        return grossWeight;
    }

    public void setGrossWeight(BigDecimal grossWeight) {
        this.grossWeight = grossWeight;
    }

    public BigDecimal getTareWeight() {
        return tareWeight;
    }

    public void setTareWeight(BigDecimal tareWeight) {
        this.tareWeight = tareWeight;
    }

    public BigDecimal getNetWeight() {
        return netWeight;
    }

    public void setNetWeight(BigDecimal netWeight) {
        this.netWeight = netWeight;
    }

    public String getWeightUnit() {
        return weightUnit;
    }

    public void setWeightUnit(String weightUnit) {
        this.weightUnit = weightUnit;
    }

    public String getGrossTime() {
        return grossTime;
    }

    public void setGrossTime(String grossTime) {
        this.grossTime = grossTime;
    }

    public String getTareTime() {
        return tareTime;
    }

    public void setTareTime(String tareTime) {
        this.tareTime = tareTime;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public String getLpId() {
        return lpId;
    }

    public void setLpId(String lpId) {
        this.lpId = lpId;
    }

    public String getThirdWeighId() {
        return thirdWeighId;
    }

    public void setThirdWeighId(String thirdWeighId) {
        this.thirdWeighId = thirdWeighId;
    }

    public String getPkDelivery() {
        return pkDelivery;
    }

    public void setPkDelivery(String pkDelivery) {
        this.pkDelivery = pkDelivery;
    }

    public String getPkDeliveryB() {
        return pkDeliveryB;
    }

    public void setPkDeliveryB(String pkDeliveryB) {
        this.pkDeliveryB = pkDeliveryB;
    }

    public String getPkWeighApply() {
        return pkWeighApply;
    }

    public void setPkWeighApply(String pkWeighApply) {
        this.pkWeighApply = pkWeighApply;
    }

    public String getPkCheck() {
        return pkCheck;
    }

    public void setPkCheck(String pkCheck) {
        this.pkCheck = pkCheck;
    }

    public Integer getCheckStatus() {
        return checkStatus;
    }

    public void setCheckStatus(Integer checkStatus) {
        this.checkStatus = checkStatus;
    }

    public String getSource() {
        return source;
    }

    public void setSource(String source) {
        this.source = source;
    }

    public Timestamp getTs() {
        return ts;
    }

    public void setTs(Timestamp ts) {
        this.ts = ts;
    }

    public BigDecimal getShipment() {
        return shipment;
    }

    public void setShipment(BigDecimal shipment) {
        this.shipment = shipment;
    }

    public String getShipedUnit() {
        return shipedUnit;
    }

    public void setShipedUnit(String shipedUnit) {
        this.shipedUnit = shipedUnit;
    }
}
